==> contour-0.5.1.7247.tar.gz: contour-0.5.1.7247/docs/features.md <==
## Main Features

:material-check-bold:{.check-mark}  Available on all 4 major platforms, Linux, macOS, FreeBSD, Windows. <br/>
:material-check-bold:{.check-mark}  GPU-accelerated rendering. <br/>
:material-check-bold:{.check-mark}  [Font ligatures](demo/font-ligatures.md) support (very useful for programming and scripting) <br/>
:material-check-bold:{.check-mark}  Unicode: Emoji support (-: 🌈  💝  😛  👪  - including ZWJ, VS15, VS16 emoji :-) <br/>
:material-check-bold:{.check-mark}  Unicode: Grapheme cluster support <br/>
:material-check-bold:{.check-mark}  Bold and italic fonts <br/>
:material-check-bold:{.check-mark}  High-DPI support. <br/>
:material-check-bold:{.check-mark}  [Vi-like input modes](input-modes.md) for improved navigation, selection and copy'n'paste experience <br/>
:material-check-bold:{.check-mark}  [Vertical Line Markers](demo/line-marks.md) (quickly jump to markers in your history!) <br/>
:material-check-bold:{.check-mark}  Blurred behind transparent background when using Windows 10 or KDE window manager on Linux. <br/>
:material-check-bold:{.check-mark}  Blurrable Background image support. <br/>
:material-check-bold:{.check-mark}  Runtime configuration reload <br/>
:material-check-bold:{.check-mark}  256-color and Truecolor support <br/>
:material-check-bold:{.check-mark}  Key binding customization <br/>
:material-check-bold:{.check-mark}  Color Schemes <br/>
:material-check-bold:{.check-mark}  Profiles (grouped customization of: color scheme, login shell, and related behaviours) <br/>
:material-check-bold:{.check-mark}  [Synchronized rendering](https://github.com/contour-terminal/contour/wiki/VTExtensions#synchronized-output) (via `SM ? 2026` / `RM ? 2026`) <br/>
:material-check-bold:{.check-mark}  Text reflow (configurable via `SM ? 2028` / `RM ? 2028`) <br/>
:material-check-bold:{.check-mark}  Clickable hyperlinks via [OSC 8](https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda) <br/>
:material-check-bold:{.check-mark}  Clipboard setting via OSC 52 <br/>
:material-check-bold:{.check-mark}  [Sixel Image support](demo/images.md) <br/>
:material-check-bold:{.check-mark}  Terminal page [buffer capture VT extension](https://github.com/contour-terminal/contour/wiki/VTExtensions#buffer-capture) to quickly extract contents. <br/>
:material-check-bold:{.check-mark}  Builtin [Fira Code inspired progress bar](https://github.com/contour-terminal/contour/issues/521) support. <br/>
:material-check-bold:{.check-mark}  Read-only mode, protecting against accidental user-input to the running application, such as <kbd>Ctrl</kbd>+<kbd>C</kbd>. <br/>
:material-check-bold:{.check-mark}  [VT320 Host-programmable and Indicator statusline support](demo/statusline.md) <br/>
:material-check-bold:{.check-mark}  [Size indicator on resize](demo/size_indicator.md) <br/>

==> contour-0.6.1.7494.tar.gz: contour-0.6.1.7494/docs/features.md <==
## Main Features

:material-check-bold:{.check-mark}  Available on all 4 major platforms, Linux, macOS, FreeBSD, Windows. <br/>
:material-check-bold:{.check-mark}  GPU-accelerated rendering. <br/>
:material-check-bold:{.check-mark}  Terminal tabs <br/>
:material-check-bold:{.check-mark}  [Font ligatures](demo/font-ligatures.md) support (very useful for programming and scripting) <br/>
:material-check-bold:{.check-mark}  Unicode: Emoji support (-: 🌈  💝  😛  👪  - including ZWJ, VS15, VS16 emoji :-) <br/>
:material-check-bold:{.check-mark}  Unicode: Grapheme cluster support <br/>
:material-check-bold:{.check-mark}  Bold and italic fonts <br/>
:material-check-bold:{.check-mark}  High-DPI support. <br/>
:material-check-bold:{.check-mark}  [Vi-like input modes](input-modes.md) for improved navigation, selection and copy'n'paste experience <br/>
:material-check-bold:{.check-mark}  [Vertical Line Markers](demo/line-marks.md) (quickly jump to markers in your history!) <br/>
:material-check-bold:{.check-mark}  Blurred behind transparent background when using Windows 10 or KDE window manager on Linux. <br/>
:material-check-bold:{.check-mark}  Blurrable Background image support. <br/>
:material-check-bold:{.check-mark}  Runtime configuration reload <br/>
:material-check-bold:{.check-mark}  256-color and Truecolor support <br/>
:material-check-bold:{.check-mark}  Key binding customization <br/>
:material-check-bold:{.check-mark}  Color Schemes <br/>
:material-check-bold:{.check-mark}  Profiles (grouped customization of: color scheme, login shell, and related behaviours) <br/>
:material-check-bold:{.check-mark}  [Synchronized rendering](vt-extensions/synchronized-output.md) (via `SM ? 2026` / `RM ? 2026`) <br/>
:material-check-bold:{.check-mark}  Text reflow (configurable via `SM ? 2028` / `RM ? 2028`) <br/>
:material-check-bold:{.check-mark}  Clickable hyperlinks via [OSC 8](https://gist.github.com/egmontkob/eb114294efbcd5adb1944c9f3cb5feda) <br/>
:material-check-bold:{.check-mark}  Clipboard setting via OSC 52 <br/>
:material-check-bold:{.check-mark}  [Sixel Image support](demo/images.md) <br/>
:material-check-bold:{.check-mark}  Terminal page [buffer capture VT extension](vt-extensions/buffer-capture.md) to quickly extract contents. <br/>
:material-check-bold:{.check-mark}  Builtin [Fira Code inspired progress bar](https://github.com/contour-terminal/contour/issues/521) support. <br/>
:material-check-bold:{.check-mark}  Read-only mode, protecting against accidental user-input to the running application, such as <kbd>Ctrl</kbd>+<kbd>C</kbd>. <br/>
:material-check-bold:{.check-mark}  [VT320 Host-programmable and Indicator statusline support](demo/statusline.md) <br/>
:material-check-bold:{.check-mark}  [Size indicator on resize](demo/size_indicator.md) <br/>
